@@ -1,5 +1,5 @@
 /* This file defines standard ELF types, structures, and macros.
-   Copyright (C) 1995-1999, 2000, 2001 Free Software Foundation, Inc.
+   Copyright (C) 1995-1999, 2000, 2001, 2003 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -2042,6 +2042,12 @@ typedef Elf32_Addr Elf32_Conflict;
 /* Keep this the last entry.  */
 #define R_390_NUM       19
 
+/* CRIS flags.  */
+#define EF_CRIS_VARIANT_MASK		0x0000000e
+#define EF_CRIS_VARIANT_ANY_V0_V10	0x00000000
+#define EF_CRIS_VARIANT_V32		0x00000002
+#define EF_CRIS_VARIANT_COMMON_V10_V32	0x00000004
+
 /* CRIS relocations.  For descriptions, see binutils or gdb:
    include/elf/cris.h */
 #define R_CRIS_NONE		0
